Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/Remmina/Remmina.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--data/ui/remmina_main.glade2
-rw-r--r--plugins/nx/nx_plugin.c16
-rw-r--r--plugins/nx/nx_session_manager.c4
-rw-r--r--plugins/rdp/rdp_plugin.c18
-rw-r--r--plugins/xdmcp/xdmcp_plugin.c22
-rw-r--r--src/remmina.c6
-rw-r--r--src/remmina_file_editor.c28
-rw-r--r--src/remmina_sftp_plugin.c8
-rw-r--r--src/remmina_ssh_plugin.c22
9 files changed, 63 insertions, 63 deletions
diff --git a/data/ui/remmina_main.glade b/data/ui/remmina_main.glade
index 6edb33322..79ca6b8a1 100644
--- a/data/ui/remmina_main.glade
+++ b/data/ui/remmina_main.glade
@@ -165,7 +165,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
<property name="can_default">True</property>
<property name="has_default">True</property>
<property name="receives_default">True</property>
- <property name="tooltip_text" translatable="yes">search string or server name/ip address for quick connect</property>
+ <property name="tooltip_text" translatable="yes">Search string or server name/IP address for "\Quick Connect\"</property>
<property name="hexpand">True</property>
<property name="width_chars">61</property>
<property name="secondary_icon_name">edit-clear</property>
diff --git a/plugins/nx/nx_plugin.c b/plugins/nx/nx_plugin.c
index 8b98f1cea..cce82d0f6 100644
--- a/plugins/nx/nx_plugin.c
+++ b/plugins/nx/nx_plugin.c
@@ -58,7 +58,7 @@ RemminaPluginService *remmina_plugin_nx_service = NULL;
static gchar *remmina_kbtype = "pc102/us";
/* When more than one NX sessions is connecting in progress, we need this mutex and array
- * to prevent them from stealing the same window id.
+ * to prevent them from stealing the same window ID.
*/
static pthread_mutex_t remmina_nx_init_mutex;
static GArray *remmina_nx_window_id_array;
@@ -88,7 +88,7 @@ static gboolean onMainThread_cb(struct onMainThread_cb_data *d)
}
pthread_mutex_unlock( &d->mu );
} else {
- /* thread has been cancelled, so we must free d memory here */
+ /* Thread has been cancelled, so we must free d memory here */
g_free( d );
}
return G_SOURCE_REMOVE;
@@ -202,7 +202,7 @@ gboolean remmina_plugin_nx_ssh_auth_callback(gchar **passphrase, gpointer userda
_("SSH credentials"), NULL,
NULL,
NULL,
- _("SSH private key passphrase"));
+ _("Password for private SSH key"));
if (ret == GTK_RESPONSE_OK) {
*passphrase = remmina_plugin_nx_service->protocol_plugin_init_get_password(gp);
return TRUE;
@@ -605,7 +605,7 @@ static gboolean remmina_plugin_nx_open_connection(RemminaProtocolWidget *gp)
if (!remmina_plugin_nx_service->gtksocket_available()) {
remmina_plugin_nx_service->protocol_plugin_set_error(gp,
- _("Protocol %s is unavailable because GtkSocket only works under X.Org"),
+ _("The protocol \"%s\" is unavailable because GtkSocket only works under X.Org."),
remmina_plugin_nx.name);
return FALSE;
}
@@ -712,7 +712,7 @@ static gpointer quality_list[] =
* c) Setting description
* d) Compact disposition
* e) Values for REMMINA_PROTOCOL_SETTING_TYPE_SELECT or REMMINA_PROTOCOL_SETTING_TYPE_COMBO
- * f) Setting Tooltip
+ * f) Setting tooltip
*/
static const RemminaProtocolSetting remmina_plugin_nx_basic_settings[] =
{
@@ -733,7 +733,7 @@ static const RemminaProtocolSetting remmina_plugin_nx_basic_settings[] =
* c) Setting description
* d) Compact disposition
* e) Values for REMMINA_PROTOCOL_SETTING_TYPE_SELECT or REMMINA_PROTOCOL_SETTING_TYPE_COMBO
- * f) Setting Tooltip
+ * f) Setting tooltip
*/
static const RemminaProtocolSetting remmina_plugin_nx_advanced_settings[] =
{
@@ -773,7 +773,7 @@ static RemminaProtocolPlugin remmina_plugin_nx =
remmina_plugin_nx_query_feature, // Query for available features
remmina_plugin_nx_call_feature, // Call a feature
NULL, // Send a keystroke
- NULL // No screenshot support available
+ NULL // Screenshot support unavailable
};
G_MODULE_EXPORT gboolean
@@ -803,7 +803,7 @@ remmina_plugin_entry(RemminaPluginService *service)
s = strchr(remmina_kbtype, ',');
if (s)
*s = '\0';
- /* g_print("NX: detected keyboard type %s\n", remmina_kbtype); */
+ /* g_print("NX: Detected \"%s\" keyboard type\n", remmina_kbtype); */
}
XCloseDisplay(dpy);
}
diff --git a/plugins/nx/nx_session_manager.c b/plugins/nx/nx_session_manager.c
index bf43628ed..39aeefa0c 100644
--- a/plugins/nx/nx_session_manager.c
+++ b/plugins/nx/nx_session_manager.c
@@ -95,7 +95,7 @@ static void remmina_nx_session_manager_on_response(GtkWidget *dialog, gint respo
event_type = response_id;
}
if (response_id == REMMINA_NX_EVENT_TERMINATE && gpdata->manager_selected) {
- remmina_nx_session_iter_set(gpdata->nx, &gpdata->iter, REMMINA_NX_SESSION_COLUMN_STATUS, _("Terminating"));
+ remmina_nx_session_iter_set(gpdata->nx, &gpdata->iter, REMMINA_NX_SESSION_COLUMN_STATUS, _("Terminating…"));
}
if (response_id != REMMINA_NX_EVENT_TERMINATE) {
gtk_widget_destroy(dialog);
@@ -108,7 +108,7 @@ static void remmina_nx_session_manager_on_response(GtkWidget *dialog, gint respo
}
/* Handle double click on a row in the NX Session manager
- * Automatically close the dialog using the default response id */
+ * Automatically close the dialog using the default response ID */
void remmina_nx_session_manager_on_row_activated(GtkTreeView *tree, GtkTreePath *path, GtkTreeViewColumn *column, RemminaProtocolWidget *gp)
{
TRACE_CALL(__func__);
diff --git a/src/remmina.c b/src/remmina.c
index 371730ef8..6a11ca388 100644
--- a/src/remmina.c
+++ b/src/remmina.c
@@ -110,7 +110,7 @@ static GOptionEntry remmina_options[] =
// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
{ "full-version", 'V', 0, G_OPTION_ARG_NONE, NULL, N_("Show version of the application and its plugins"), NULL },
// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
- { "update-profile", 0, 0, G_OPTION_ARG_FILENAME, NULL, N_("Modify connection profile, (requires --set-option)"), NULL },
+ { "update-profile", 0, 0, G_OPTION_ARG_FILENAME, NULL, N_("Modify connection profile (requires --set-option)"), NULL },
// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
{ "set-option", 0, 0, G_OPTION_ARG_STRING_ARRAY, NULL, N_("Set one or more profile settings, to be used with --update-profile"), NULL },
{ NULL }
@@ -250,10 +250,10 @@ static void remmina_on_startup(GApplication *app)
* something is missing */
secret_plugin = remmina_plugin_manager_get_secret_plugin();
if (!secret_plugin) {
- g_print("WARNING: Remmina is running without a secret plugin. Passwords will be saved in a less secure way.\n");
+ g_print("Warning: Remmina is running without a secret plugin. Passwords will be saved in a less secure way.\n");
} else {
if (!secret_plugin->is_service_available())
- g_print("WARNING: Remmina is running with a secret plugin, but it cannot connect to a secret service.\n");
+ g_print("Warning: Remmina is running with a secrecy plugin, but it cannot connect to a secrecy service.\n");
}
remmina_exec_command(REMMINA_COMMAND_AUTOSTART, NULL);
diff --git a/src/remmina_file_editor.c b/src/remmina_file_editor.c
index 3d39b7123..41b5574a2 100644
--- a/src/remmina_file_editor.c
+++ b/src/remmina_file_editor.c
@@ -917,7 +917,7 @@ static void remmina_file_editor_create_ssh_tab(RemminaFileEditor *gfe, RemminaPr
_("Username"), NULL);
row++;
}
- widget = gtk_radio_button_new_with_label(NULL, _("SSH Agent (automatic)"));
+ widget = gtk_radio_button_new_with_label(NULL, _("SSH agent (automatic)"));
gtk_grid_attach(GTK_GRID(grid), widget, 0, row + 19, 1, 1);
priv->ssh_auth_agent_radio = widget;
row++;
@@ -991,7 +991,7 @@ static void remmina_file_editor_create_all_settings(RemminaFileEditor *gfe)
static const RemminaProtocolSetting autostart_settings[] =
{
- { REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "enable-autostart", N_("Turn on autostart for this profile"), FALSE, NULL, NULL },
+ { REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "enable-autostart", N_("Turn on \"Autostart\" for this profile"), FALSE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_END, NULL, NULL, FALSE, NULL, NULL }
};
@@ -1177,7 +1177,7 @@ static void remmina_file_editor_update(RemminaFileEditor *gfe)
if (priv->resolution_auto_radio) {
if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(priv->resolution_auto_radio))) {
- /* Resolution is set to auto (which means: use client fullscreen resolution, aka use client resolution) */
+ /* Resolution is set to auto (which means: Use client fullscreen resolution, aka use client resolution) */
res_w = res_h = 0;
res_mode = RES_USE_CLIENT;
} else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(priv->resolution_iws_radio))) {
@@ -1255,7 +1255,7 @@ static void remmina_file_editor_on_connect(GtkWidget *button, RemminaFileEditor
remmina_file_editor_update(gfe);
gf = remmina_file_dup(gfe->priv->remmina_file);
- /* Put server into name for Quick Connect */
+ /* Put server into name for "Quick Connect" */
if (remmina_file_get_filename(gf) == NULL)
remmina_file_set_string(gf, "name", remmina_file_get_string(gf, "server"));
gtk_widget_destroy(GTK_WIDGET(gfe));
@@ -1266,7 +1266,7 @@ static void remmina_file_editor_on_connect(GtkWidget *button, RemminaFileEditor
static void remmina_file_editor_on_save_connect(GtkWidget *button, RemminaFileEditor *gfe)
{
TRACE_CALL(__func__);
- /** @todo Call remmina_file_editor_on_save */
+ /** @TODO: Call remmina_file_editor_on_save */
RemminaFile *gf;
remmina_file_editor_update(gfe);
@@ -1372,7 +1372,7 @@ static void remmina_file_editor_entry_on_changed(GtkEditable *editable, RemminaF
priv = gfe->priv;
if (remmina_file_get_filename(priv->remmina_file) == NULL) {
remmina_file_generate_filename(priv->remmina_file);
- /* TODO Probably to be removed */
+ /* TODO: Probably to be removed */
remmina_file_editor_check_profile(gfe);
} else {
remmina_file_delete(remmina_file_get_filename(priv->remmina_file));
@@ -1414,7 +1414,7 @@ GtkWidget *remmina_file_editor_new_from_file(RemminaFile *remminafile)
if (remmina_file_get_filename(remminafile) == NULL)
gtk_dialog_set_response_sensitive(GTK_DIALOG(gfe), GTK_RESPONSE_APPLY, FALSE);
- /* Create the Profile group on the top (for name and protocol) */
+ /* Create the "Profile" group on the top (for name and protocol) */
grid = gtk_grid_new();
gtk_widget_show(grid);
gtk_grid_set_row_spacing(GTK_GRID(grid), 4);
@@ -1482,8 +1482,8 @@ GtkWidget *remmina_file_editor_new_from_file(RemminaFile *remminafile)
remmina_plugin_manager_for_each_plugin(REMMINA_PLUGIN_TYPE_PROTOCOL, remmina_file_editor_iterate_protocol, gfe);
g_signal_connect(G_OBJECT(widget), "changed", G_CALLBACK(remmina_file_editor_protocol_combo_on_changed), gfe);
- /* Prior Connection Command */
- widget = gtk_label_new(_("Pre Command"));
+ /* Prior connection command */
+ widget = gtk_label_new(_("Pre-command"));
gtk_widget_show(widget);
gtk_widget_set_valign(widget, GTK_ALIGN_START);
gtk_widget_set_halign(widget, GTK_ALIGN_START);
@@ -1500,8 +1500,8 @@ GtkWidget *remmina_file_editor_new_from_file(RemminaFile *remminafile)
gtk_entry_set_placeholder_text(GTK_ENTRY(widget), "command %h %u %t %U %p %g --option");
gtk_widget_set_tooltip_markup(widget, _(cmd_tips));
- /* POST Connection Command */
- widget = gtk_label_new(_("Post Command"));
+ /* POST connection command */
+ widget = gtk_label_new(_("Post-command"));
gtk_widget_show(widget);
gtk_widget_set_valign(widget, GTK_ALIGN_START);
gtk_widget_set_halign(widget, GTK_ALIGN_START);
@@ -1518,7 +1518,7 @@ GtkWidget *remmina_file_editor_new_from_file(RemminaFile *remminafile)
gtk_entry_set_placeholder_text(GTK_ENTRY(widget), "/path/to/command -opt1 arg %h %u %t -opt2 %U %p %g");
gtk_widget_set_tooltip_markup(widget, _(cmd_tips));
- /* Create the Preference frame */
+ /* Create the "Preference" frame */
widget = gtk_event_box_new();
gtk_widget_show(widget);
gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(gfe))), widget, TRUE, TRUE, 2);
@@ -1566,7 +1566,7 @@ GtkWidget *remmina_file_editor_new_copy(const gchar *filename)
return remmina_file_editor_new_from_file(remminafile);
} else {
dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
- _("File %s not found."), filename);
+ _("Could not find the file \"%s\"."), filename);
gtk_dialog_run(GTK_DIALOG(dialog));
gtk_widget_destroy(dialog);
return NULL;
@@ -1584,7 +1584,7 @@ GtkWidget *remmina_file_editor_new_from_filename(const gchar *filename)
return remmina_file_editor_new_from_file(remminafile);
} else {
dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
- _("File %s not found."), filename);
+ _("Could not find the file \"%s\"."), filename);
gtk_dialog_run(GTK_DIALOG(dialog));
gtk_widget_destroy(dialog);
return NULL;
diff --git a/src/remmina_sftp_plugin.c b/src/remmina_sftp_plugin.c
index 07698ebb9..49f487646 100644
--- a/src/remmina_sftp_plugin.c
+++ b/src/remmina_sftp_plugin.c
@@ -242,7 +242,7 @@ remmina_plugin_sftp_open_connection(RemminaProtocolWidget *gp)
if (pthread_create(&gpdata->thread, NULL, remmina_plugin_sftp_main_thread, gp)) {
remmina_plugin_service->protocol_plugin_set_error(gp,
- "Failed to initialize pthread. Falling back to non-thread mode…");
+ "Could not initialize pthread. Falling back to non-thread mode…");
gpdata->thread = 0;
return FALSE;
} else {
@@ -347,10 +347,10 @@ static const RemminaProtocolSetting remmina_sftp_basic_settings[] =
{
{ REMMINA_PROTOCOL_SETTING_TYPE_SERVER, "ssh_server", NULL, FALSE, "_sftp-ssh._tcp", NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_TEXT, "ssh_username", N_("Username"), FALSE, NULL, NULL },
- { REMMINA_PROTOCOL_SETTING_TYPE_PASSWORD, "ssh_password", N_("User password"), FALSE, NULL, NULL },
+ { REMMINA_PROTOCOL_SETTING_TYPE_PASSWORD, "ssh_password", N_("Password"), FALSE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_SELECT, "ssh_auth", N_("Authentication type"), FALSE, ssh_auth, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_FILE, "ssh_privatekey", N_("Identity file"), FALSE, NULL, NULL },
- { REMMINA_PROTOCOL_SETTING_TYPE_PASSWORD, "ssh_passphrase", N_("Private key passphrase"), FALSE, NULL, NULL },
+ { REMMINA_PROTOCOL_SETTING_TYPE_PASSWORD, "ssh_passphrase", N_("Password to unlock private key"), FALSE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_END, NULL, NULL, FALSE, NULL, NULL }
};
@@ -374,7 +374,7 @@ static RemminaProtocolPlugin remmina_plugin_sftp =
remmina_plugin_sftp_query_feature, // Query for available features
remmina_plugin_sftp_call_feature, // Call a feature
NULL, // Send a keystroke
- NULL // No screenshot support available
+ NULL // Screenshot support unavailable
};
void
diff --git a/src/remmina_ssh_plugin.c b/src/remmina_ssh_plugin.c
index cb4b85d0c..a560e24a5 100644
--- a/src/remmina_ssh_plugin.c
+++ b/src/remmina_ssh_plugin.c
@@ -211,7 +211,7 @@ remmina_plugin_ssh_on_size_allocate(GtkWidget *widget, GtkAllocation *alloc, Rem
/**
- * Remmina Protocol plugin main function.
+ * Remmina protocol plugin main function.
*
* First it starts the SSH tunnel if needed and then the SSH connection.
*
@@ -285,7 +285,7 @@ remmina_plugin_ssh_main_thread(gpointer data)
ssh = g_object_get_data(G_OBJECT(gp), "user-data");
if (ssh) {
- /* Create SSH Shell connection based on existing SSH session */
+ /* Create SSH shell connection based on existing SSH session */
shell = remmina_ssh_shell_new_from_ssh(ssh);
if (remmina_ssh_init_session(REMMINA_SSH(shell)) &&
remmina_ssh_auth(REMMINA_SSH(shell), NULL, gp, remminafile) > 0 &&
@@ -339,7 +339,7 @@ remmina_plugin_ssh_main_thread(gpointer data)
gchar *charset = REMMINA_SSH(shell)->charset;
remmina_plugin_ssh_vte_terminal_set_encoding_and_pty(VTE_TERMINAL(gpdata->vte), charset, shell->master, shell->slave);
- /* ToDo: the following call should be moved on the main thread, or something weird could happen */
+ /* TODO: The following call should be moved on the main thread, or something weird could happen */
remmina_plugin_ssh_on_size_allocate(GTK_WIDGET(gpdata->vte), NULL, gp);
remmina_plugin_service->protocol_plugin_signal_connection_opened(gp);
@@ -1058,7 +1058,7 @@ static const RemminaProtocolSetting remmina_ssh_basic_settings[] =
{ REMMINA_PROTOCOL_SETTING_TYPE_PASSWORD, "ssh_password", N_("User password"), FALSE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_SELECT, "ssh_auth", N_("Authentication type"), FALSE, ssh_auth, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_FILE, "ssh_privatekey", N_("Identity file"), FALSE, NULL, NULL },
- { REMMINA_PROTOCOL_SETTING_TYPE_PASSWORD, "ssh_passphrase", N_("Private key passphrase"), FALSE, NULL, NULL },
+ { REMMINA_PROTOCOL_SETTING_TYPE_PASSWORD, "ssh_passphrase", N_("Password to unlock private key"), FALSE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_TEXT, "exec", N_("Startup program"), FALSE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_END, NULL, NULL, FALSE, NULL, NULL }
};
@@ -1082,12 +1082,12 @@ static const RemminaProtocolSetting remmina_ssh_advanced_settings[] =
{ REMMINA_PROTOCOL_SETTING_TYPE_TEXT, "ssh_kex_algorithms", N_("KEX (Key Exchange) algorithms"), FALSE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_TEXT, "ssh_ciphers", N_("Symmetric cipher client to server"), FALSE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_TEXT, "ssh_hostkeytypes", N_("Preferred server host key types"), FALSE, NULL, NULL },
- { REMMINA_PROTOCOL_SETTING_TYPE_FOLDER, "sshlogfolder", N_("SSH session log folder"), FALSE, NULL, NULL },
- { REMMINA_PROTOCOL_SETTING_TYPE_TEXT, "sshlogname", N_("SSH session log file name"), FALSE, NULL, NULL },
- { REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "sshlogenabled", N_("Enable SSH session logging at exit"), FALSE, NULL, NULL },
- { REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "audiblebell", N_("Enable terminal audible bell"), FALSE, NULL, NULL },
- { REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "ssh_compression", N_("Enable SSH compression"), FALSE, NULL, NULL },
- { REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "disablepasswordstoring", N_("Disable password storing"), TRUE, NULL, NULL },
+ { REMMINA_PROTOCOL_SETTING_TYPE_FOLDER, "sshlogfolder", N_("Folder for SSH session log"), FALSE, NULL, NULL },
+ { REMMINA_PROTOCOL_SETTING_TYPE_TEXT, "sshlogname", N_("Filename for SSH session log"), FALSE, NULL, NULL },
+ { REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "sshlogenabled", N_("Log SSH session when exiing Remmina"), FALSE, NULL, NULL },
+ { REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "audiblebell", N_("Audible terminal bell"), FALSE, NULL, NULL },
+ { REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "ssh_compression", N_("SSH compression"), FALSE, NULL, NULL },
+ { REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "disablepasswordstoring", N_("Don't remember passwords"), TRUE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "ssh_stricthostkeycheck", N_("Strict host key checking"), TRUE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_END, NULL, NULL, FALSE, NULL, NULL }
};
@@ -1153,7 +1153,7 @@ remmina_ssh_plugin_load_terminal_palettes(gpointer *ssh_terminal_palette_new)
gchar *remmina_dir = g_build_path("/", dirs[i], "remmina", "theme", NULL);
system_data_dir = g_dir_open(remmina_dir, 0, &error);
g_free(remmina_dir);
- // ignoring this error is ok, because the folder may not existing
+ // ignoring this error is OK, because the folder may not exist
if (error) {
g_error_free(error);
error = NULL;
diff --git a/plugins/rdp/rdp_plugin.c b/plugins/rdp/rdp_plugin.c
index 9c5a3ab40..f5b302e33 100644
--- a/plugins/rdp/rdp_plugin.c
+++ b/plugins/rdp/rdp_plugin.c
@@ -1565,7 +1565,7 @@ static gboolean remmina_rdp_main(RemminaProtocolWidget *gp)
remmina_plugin_service->protocol_plugin_set_error(gp, _("Could not start libfreerdp-gdi"));
break;
case REMMINA_POSTCONNECT_ERROR_NO_H264:
- remmina_plugin_service->protocol_plugin_set_error(gp, _("You requested a H.264 GFX mode for server %s, but your libfreerdp does not support H.264. Please use a non-AVC color depth setting."), rfi->settings->ServerHostname);
+ remmina_plugin_service->protocol_plugin_set_error(gp, _("You requested a H.264 GFX mode for server %s, but your libfreerdp does not support H.264. Please use a non-AVC colour depth setting."), rfi->settings->ServerHostname);
break;
}
break;
@@ -1865,7 +1865,7 @@ static gboolean remmina_rdp_get_screenshot(RemminaProtocolWidget *gp, RemminaPlu
return TRUE;
}
/* Array of key/value pairs for color depths */
static gpointer colordepth_list[] =
{
/* 1st one is the default in a new install */
@@ -1873,11 +1873,11 @@ static gpointer colordepth_list[] =
"65", N_("GFX AVC420 (32 bpp)"),
"64", N_("GFX RFX (32 bpp)"),
"0", N_("RemoteFX (32 bpp)"),
- "32", N_("True color (32 bpp)"),
- "24", N_("True color (24 bpp)"),
- "16", N_("High color (16 bpp)"),
- "15", N_("High color (15 bpp)"),
- "8", N_("256 colors (8 bpp)"),
+ "32", N_("True colour (32 bpp)"),
+ "24", N_("True colour (24 bpp)"),
+ "16", N_("High colour (16 bpp)"),
+ "15", N_("High colour (15 bpp)"),
+ "8", N_("256 colours (8 bpp)"),
NULL
};
@@ -1937,7 +1937,7 @@ static const RemminaProtocolSetting remmina_rdp_basic_settings[] =
{ REMMINA_PROTOCOL_SETTING_TYPE_PASSWORD, "password", N_("User password"), FALSE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_TEXT, "domain", N_("Domain"), FALSE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_RESOLUTION, "resolution", NULL, FALSE, NULL, NULL },
- { REMMINA_PROTOCOL_SETTING_TYPE_SELECT, "colordepth", N_("Color depth"), FALSE, colordepth_list, NULL },
+ { REMMINA_PROTOCOL_SETTING_TYPE_SELECT, "colordepth", N_("Colour depth"), FALSE, colordepth_list, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_FOLDER, "sharefolder", N_("Share folder"), FALSE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_END, NULL, NULL, FALSE, NULL, NULL }
};
@@ -1974,7 +1974,7 @@ static const RemminaProtocolSetting remmina_rdp_advanced_settings[] =
{ REMMINA_PROTOCOL_SETTING_TYPE_TEXT, "smartcardname", N_("Smartcard name"), FALSE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "shareprinter", N_("Share printers"), TRUE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "shareserial", N_("Share serial ports"), TRUE, NULL, NULL },
- { REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "serialpermissive", N_("Serial ports permissive mode"), TRUE, NULL, NULL },
+ { REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "serialpermissive", N_("(SELinux) permissive mode for serial ports"), TRUE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "shareparallel", N_("Share parallel ports"), TRUE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "sharesmartcard", N_("Share smartcard"), TRUE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "microphone", N_("Redirect local microphone"), TRUE, NULL, NULL },
@@ -1865,7 +1865,7 @@ static gboolean remmina_rdp_get_screenshot(RemminaProtocolWidget *gp, RemminaPlu
return TRUE;
}
-/* Array of key/value pairs for color depths */
+/* Array of key/value pairs for colour depths */
static gpointer colordepth_list[] =
{
diff --git a/plugins/xdmcp/xdmcp_plugin.c b/plugins/xdmcp/xdmcp_plugin.c
index 97f71fc31..bfdd96377 100644
--- a/plugins/xdmcp/xdmcp_plugin.c
+++ b/plugins/xdmcp/xdmcp_plugin.c
@@ -106,10 +106,10 @@ static gboolean remmina_plugin_xdmcp_start_xephyr(RemminaProtocolWidget *gp)
argv[argc++] = g_strdup("-parent");
argv[argc++] = g_strdup_printf("%i", gpdata->socket_id);
/* All Xephyr version between 1.5.0 and 1.6.4 will break when -screen argument is specified with -parent.
* It’s not possible to support color depth if you have those Xephyr version. Please see this bug
* http://bugs.freedesktop.org/show_bug.cgi?id=24144
* As a workaround, a "Default" color depth will not add the -screen argument.
*/
i = remmina_plugin_service->file_get_int(remminafile, "colordepth", 8);
if (i >= 8) {
@@ -261,7 +261,7 @@ static gboolean remmina_plugin_xdmcp_open_connection(RemminaProtocolWidget *gp)
if (!remmina_plugin_service->gtksocket_available()) {
remmina_plugin_service->protocol_plugin_set_error(gp,
- _("Protocol %s is unavailable because GtkSocket only works under X.Org"),
+ _("The protocol \"%s\" is unavailable because GtkSocket only works under X.Org."),
remmina_plugin_xdmcp.name);
return FALSE;
}
@@ -312,7 +312,7 @@ static gboolean remmina_plugin_xdmcp_close_connection(RemminaProtocolWidget *gp)
return FALSE;
}
-/* Send CTRL+ALT+DEL keys keystrokes to the plugin socket widget */
+/* Send Ctrl+Alt+Del keys keystrokes to the plugin socket widget */
static void remmina_plugin_xdmcp_send_ctrlaltdel(RemminaProtocolWidget *gp)
{
TRACE_CALL(__func__);
@@ -342,14 +342,14 @@ static void remmina_plugin_xdmcp_call_feature(RemminaProtocolWidget *gp, const R
}
}
/* Array of key/value pairs for color depths */
static gpointer colordepth_list[] =
{
"0", N_("Default"),
"2", N_("Grayscale"),
- "8", N_("256 colors"),
- "16", N_("High color (16 bit)"),
- "24", N_("True color (24 bit)"),
+ "8", N_("256 colours"),
+ "16", N_("High colour (16 bit)"),
+ "24", N_("True colour (24 bit)"),
NULL
};
@@ -360,13 +360,13 @@ static gpointer colordepth_list[] =
* c) Setting description
* d) Compact disposition
* e) Values for REMMINA_PROTOCOL_SETTING_TYPE_SELECT or REMMINA_PROTOCOL_SETTING_TYPE_COMBO
- * f) Setting Tooltip
+ * f) Setting tooltip
*/
static const RemminaProtocolSetting remmina_plugin_xdmcp_basic_settings[] =
{
{ REMMINA_PROTOCOL_SETTING_TYPE_SERVER, "server", NULL, FALSE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_RESOLUTION, "resolution", NULL, FALSE, NULL, NULL },
- { REMMINA_PROTOCOL_SETTING_TYPE_SELECT, "colordepth", N_("Color depth"), FALSE, colordepth_list, NULL },
+ { REMMINA_PROTOCOL_SETTING_TYPE_SELECT, "colordepth", N_("Colour depth"), FALSE, colordepth_list, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_TEXT, "exec", N_("Startup program"), FALSE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "showcursor", N_("Use local cursor"), FALSE, NULL, NULL },
{ REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "once", N_("Disconnect after first session"), FALSE, NULL, NULL },
@@ -106,10 +106,10 @@ static gboolean remmina_plugin_xdmcp_start_xephyr(RemminaProtocolWidget *gp)
argv[argc++] = g_strdup("-parent");
argv[argc++] = g_strdup_printf("%i", gpdata->socket_id);
- /* All Xephyr version between 1.5.0 and 1.6.4 will break when -screen argument is specified with -parent.
- * It’s not possible to support color depth if you have those Xephyr version. Please see this bug
+ /* All Xephyr version between 1.5.0 and 1.6.4 will break when "-screen" argument is specified with "-parent".
+ * It’s not possible to support colour depth if you have those Xephyr version. Please see this bug
* http://bugs.freedesktop.org/show_bug.cgi?id=24144
@@ -106,10 +106,10 @@ static gboolean remmina_plugin_xdmcp_start_xephyr(RemminaProtocolWidget *gp)
* http://bugs.freedesktop.org/show_bug.cgi?id=24144
- * As a workaround, a "Default" color depth will not add the -screen argument.
+ * As a workaround, a "Default" colour depth will not add the "-screen" argument.
*/
i = remmina_plugin_service->file_get_int(remminafile, "colordepth", 8);
@@ -342,14 +342,14 @@ static void remmina_plugin_xdmcp_call_feature(RemminaProtocolWidget *gp, const R
}
}
-/* Array of key/value pairs for color depths */
+/* Array of key/value pairs for colour depths */
static gpointer colordepth_list[] =
{